module.exports = defineTest({
	description: 'removes the last element of a sequence expression if it is unused'
});
